@@ -453,9 +453,10 @@ pub fn last() -> Term {
     app(
         z(),
         abs!(2, app!(
-            null(),
             Var(1),
-            abs(fls()),
+            abs!(5, Var(1)),
+            abs!(2, Var(2)),
+            abs!(3, Var(1)),
             abs(app!(
                 Var(2),
                 abs!(2, Var(1)),
@@ -469,6 +470,233 @@ pub fn last() -> Term {
     )
 }
 
+/// Applied to a Church-encoded list it returns the list without the last element.
+///
+/// INIT := Z (λzl.NULL l (λx.NIL) (λx.(NULL (FST l) NIL (PAIR (FST l) (z (SND l))))) I) =
+/// Z (λ λ NULL 1 (λ NIL) (λ (NULL (FST 2) NIL (PAIR (FST 2) (3 (SND 2))))) I)
+///
+/// # Example
+/// ```
+/// use lambda_calculus::church::lists::init;
+/// use lambda_calculus::*;
+///
+/// let list1 = Term::from(vec![0.into(), 1.into(), 2.into(), 3.into()]);
+/// let list2 = Term::from(vec![0.into(), 1.into(), 2.into()]);
+///
+/// assert_eq!(beta(app(init(), list1), NOR, 0, false), list2);
+/// ```
+pub fn init() -> Term {
+    app(
+        z(),
+        abs!(2, app!(
+            Var(1),
+            abs!(5, Var(1)),
+            abs!(2, Var(2)),
+            abs!(3, Var(1)),
+            abs(app!(
+                Var(2),
+                abs!(2, Var(1)),
+                abs!(5, Var(1)),
+                abs!(2, Var(2)),
+                abs!(2, Var(1)),
+                abs(app!(
+                    Var(1),
+                    app(Var(3), abs!(2, Var(2))),
+                    app(Var(4), app(Var(3), abs!(2, Var(1))))
+                ))
+            )),
+            abs(Var(1))
+        ))
+    )
+}
+
+/// Applied to two Church-encoded lists it returns a list of corresponding pairs. If one input list
+/// is shorter, excess elements of the longer list are discarded.
+///
+/// ZIP := Z (λ.zab NULL b (λ.x NIL) (λ.x NULL a NIL (CONS (PAIR (HEAD b) (HEAD a)) (z (TAIL b) (TAIL a)))) I) =
+/// Z (λ λ λ NULL 2 (λ NIL) (λ NULL 2 NIL (CONS (PAIR (HEAD 3) (HEAD 2)) (4 (TAIL 3) (TAIL 2)))) I)
+///
+/// # Example
+/// ```
+/// use lambda_calculus::church::lists::zip;
+/// use lambda_calculus::*;
+///
+/// let list1 = Term::from(vec![0.into(), 1.into()]);
+/// let pairs1 = Term::from(vec![(0.into(), 0.into()).into(), (1.into(), 1.into()).into()]);
+///
+/// assert_eq!(beta(app!(zip(), list1.clone(), list1.clone()), NOR, 0, false), pairs1);
+/// ```
+pub fn zip() -> Term {
+    app(
+        z(),
+        abs!(3, app!(
+            Var(2),
+            abs!(5, Var(1)),
+            abs!(2, Var(2)),
+            abs!(3, Var(1)),
+            abs(app!(
+                Var(2),
+                abs!(5, Var(1)),
+                abs!(2, Var(2)),
+                abs!(2, Var(1)),
+                abs(app!(
+                    Var(1),
+                    abs(app!(
+                        Var(1),
+                        app(Var(5), abs!(2, Var(2))),
+                        app(Var(4), abs!(2, Var(2)))
+                    )),
+                    app!(
+                        Var(5),
+                        app(Var(4), abs!(2, Var(1))),
+                        app(Var(3), abs!(2, Var(1)))
+                    )
+                ))
+            )),
+            abs(Var(1))
+        ))
+    )
+}
+
+/// Applied to a function and two Church-encoded lists it applies the function to the corresponding
+/// elements and returns the resulting list. If one input list is shorter, excess elements of the
+/// longer list are discarded.
+///
+/// ZIP_WITH := Z (λ.zfab NULL b (λ.x NIL) (λ.x NULL a NIL (CONS (f (HEAD b) (HEAD a)) (z f (TAIL b) (TAIL a)))) I) =
+/// Z (λ λ λ λ NULL 2 (λ NIL) (λ NULL 2 NIL (CONS (4 (HEAD 3) (HEAD 2)) (5 4 (TAIL 3) (TAIL 2)))) I)
+///
+/// # Example
+/// ```
+/// use lambda_calculus::church::lists::zip_with;
+/// use lambda_calculus::church::numerals::plus;
+/// use lambda_calculus::*;
+///
+/// let list1 = Term::from(vec![2.into(), 3.into()]);
+/// let list2 = Term::from(vec![4.into(), 6.into()]);
+///
+/// assert_eq!(beta(app!(zip_with(), plus(), list1.clone(), list1), NOR, 0, false), list2);
+/// ```
+pub fn zip_with() -> Term {
+    app(
+        z(),
+        abs!(4, app!(
+            Var(2),
+            abs!(5, Var(1)),
+            abs!(2, Var(2)),
+            abs!(3, Var(1)),
+            abs(app!(
+                Var(2),
+                abs!(5, Var(1)),
+                abs!(2, Var(2)),
+                abs!(2, Var(1)),
+                abs(app!(
+                    Var(1),
+                    app!(
+                        Var(5),
+                        app(Var(4), abs!(2, Var(2))),
+                        app(Var(3), abs!(2, Var(2)))
+                    ),
+                    app!(
+                        Var(6),
+                        Var(5),
+                        app(Var(4), abs!(2, Var(1))),
+                        app(Var(3), abs!(2, Var(1)))
+                    )
+                ))
+            )),
+            abs(Var(1))
+        ))
+    )
+}
+
+/// Applied to a Church-encoded number `n` and a Church-encoded list it returns a new list with the
+/// first `n` elements of the supplied list.
+///
+/// TAKE := Z (λznl. NULL l (λx.NIL) (λx.IS_ZERO n NIL (CONS (HEAD l) (z (PRED n) (TAIL l)))) I) =
+/// Z (λ λ λ NULL l (λ NIL) (λ (IS_ZERO n NIL (CONS (HEAD l) (z (PRED n) (TAIL l))))) I)
+///
+/// # Example
+/// ```
+/// use lambda_calculus::church::lists::take;
+/// use lambda_calculus::*;
+///
+/// let list1 = Term::from(vec![0.into(), 1.into(), 2.into(), 3.into()]);
+/// let list2 = Term::from(vec![0.into(), 1.into()]);
+///
+/// assert_eq!(beta(app!(take(), 2.into(), list1), NOR, 0, false), list2);
+pub fn take() -> Term {
+    app(
+        z(),
+        abs!(3, app!(
+            Var(1),
+            abs!(5, Var(1)),
+            abs!(2, Var(2)),
+            abs!(3, Var(1)),
+            abs(app!(
+                Var(3),
+                abs!(3, Var(1)),
+                abs!(2, Var(2)),
+                abs!(2, Var(1)),
+                abs(app!(
+                    Var(1),
+                    app(Var(3), abs!(2, Var(2))),
+                    app!(
+                        Var(5),
+                        abs!(2, app!(
+                            Var(6),
+                            abs!(2, app(Var(1), app(Var(2), Var(4)))),
+                            abs(Var(2)),
+                            abs(Var(1))
+                        )),
+                        app(Var(3), abs!(2, Var(1)))
+                    )
+                ))
+            )),
+            abs(Var(1))
+        ))
+    )
+}
+
+/// Applied to a predicate function and a Church-encoded list it returns the longest prefix of the
+/// list whose elements all satisfy the predicate function.
+///
+/// TAKE_WHILE := Z (λzfl. NULL l (λx.NIL) (λx.f (HEAD l) (CONS (HEAD l) (z f (TAIL l))) NIL) I) =
+/// Z (λ λ λ NULL 1 (λ NIL) (λ 3 (HEAD 2) (CONS (HEAD 2) (4 3 (TAIL 2))) NIL) I)
+///
+/// # Example
+/// ```
+/// use lambda_calculus::church::lists::take_while;
+/// use lambda_calculus::church::numerals::is_zero;
+/// use lambda_calculus::*;
+///
+/// let list1 = Term::from(vec![0.into(), 0.into(), 1.into()]);
+/// let list2 = Term::from(vec![0.into(), 0.into()]);
+///
+/// assert_eq!(beta(app!(take_while(), is_zero(), list1), NOR, 0, false), list2);
+/// ```
+pub fn take_while() -> Term {
+    app(
+        z(),
+        abs!(3, app!(
+            Var(1),
+            abs!(5, Var(1)),
+            abs!(2, Var(1)),
+            abs!(3, Var(1)),
+            abs(app!(
+                Var(3),
+                app(Var(2), abs!(2, Var(2))),
+                abs(app!(
+                    Var(1),
+                    app(Var(3), abs!(2, Var(2))),
+                    app!(Var(5), Var(4), app(Var(3), abs!(2, Var(1))))
+                )),
+                abs!(2, Var(1))
+            )),
+            abs(Var(1))
+        ))
+    )
+}
+
 impl Term {
     /// Checks whether self is a empty Church list, i.e. `nil()`.
     ///
