@@ -10,6 +10,10 @@ pub mod reduction;
 pub mod combinators;
 #[cfg(not(feature = "no_church"))]
 pub mod church;
+#[cfg(feature = "scott")]
+pub mod scott;
+#[cfg(feature = "parigot")]
+pub mod parigot;
 
 pub use self::term::{Term, abs, app};
 pub use self::term::Term::*;
