@@ -4,6 +4,7 @@ use term::{Term, Error, show_precedence_cla};
 use term::Term::*;
 use std::fmt;
 use std::io::{Write, BufWriter, stdout};
+use std::mem;
 pub use self::Order::*;
 
 /// The [evaluation order](http://www.cs.cornell.edu/courses/cs6110/2014sp/Handouts/Sestoft.pdf) of
@@ -144,7 +145,8 @@ pub fn compare(term: &Term, orders: &[Order], verbose: bool) {
 
     writeln!(buf, "comparing β-reduction strategies for {}:\n", term).unwrap();
     for order in orders {
-        writeln!(buf, "{}:{}{}", order,
+        writeln!(buf, "{}:{}{}",
+            order,
             " ".repeat(19 - format!("{}", order).len()),
             term.to_owned().beta(*order, 0, verbose)
         ).unwrap();
@@ -185,7 +187,7 @@ impl Term {
     /// The function will return an error if `self` is not an `App`lication or if its left hand
     /// side term is not an `Abs`traction.
     pub fn eval(self) -> Result<Term, Error> {
-        let (lhs, rhs) = try!(self.unapp());
+        let (lhs, rhs) = self.unapp()?;
 
         apply(lhs, &rhs)
     }
@@ -193,8 +195,9 @@ impl Term {
     fn eval_with_info(&mut self, depth: u32, count: &mut usize, verbose: bool) {
         if verbose { println!("\n{}. {}", *count + 1, show_precedence_cla(self, 0, depth)) }
 
-        let copy = self.clone();
-        *self = copy.eval().unwrap(); // safe; only called in reduction sites
+        let mut to_eval = mem::replace(self, Var(0)); // replace self with a dummy
+        to_eval = to_eval.eval().unwrap(); // safe; only called in reduction sites
+        mem::replace(self, to_eval); // move self back to its place
         *count += 1;
 
         if verbose {
@@ -229,7 +232,9 @@ impl Term {
     /// ```
     pub fn beta(&mut self, order: Order, limit: usize, verbose: bool) -> usize {
         if verbose {
-            println!("β-reducing {} [{} order{}]:", self, order,
+            println!("β-reducing {} [{} order{}]:",
+                self,
+                order,
                 if limit != 0 {
                     format!(", limit of {} reduction{}", limit, if limit == 1 { "" } else { "s" })
                 } else {
@@ -251,8 +256,10 @@ impl Term {
         }
 
         if verbose {
-            println!("\nresult after {} reduction{}: {}\n", count,
-                if count == 1 { "" } else { "s" }, self);
+            println!("\nresult after {} reduction{}: {}\n",
+                count,
+                if count == 1 { "" } else { "s" }, self
+            );
         };
 
         count
