@@ -323,8 +323,7 @@ impl fmt::Display for Term {
     }
 }
 
-#[doc(hidden)]
-pub fn show_precedence_cla(term: &Term, context_precedence: usize, depth: u32) -> String {
+pub(crate) fn show_precedence_cla(term: &Term, context_precedence: usize, depth: u32) -> String {
     match *term {
         Var(i) => {
             if depth >= i as u32 {
@@ -359,8 +358,7 @@ impl fmt::Debug for Term {
     }
 }
 
-#[doc(hidden)]
-pub fn show_precedence_dbr(term: &Term, context_precedence: usize, depth: u32) -> String {
+pub(crate) fn show_precedence_dbr(term: &Term, context_precedence: usize, depth: u32) -> String {
     match *term {
         Var(i) => {
             format!("{:X}", i)
